aetherel

package module
v0.0.0-...-2557dda Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 18, 2024 License: MIT Imports: 3 Imported by: 0

README

Aetherel is a new, full-stack Golang web library. It makes strict choices for dependencies, reducing both the options and boilerplate for you as a developer, and allowing you to focus on your actual business logic.

Aetherel is currently in development, expect bugs and do not use any of this in production.

The technologies used in Aetherel are:

  • echo server
  • templ templating engine
  • postgresql database
  • goose migrations
  • sqlc database queries

Coming soon (technologies subject to change):

  • HTMX
  • Svelte components for high interactivity
  • Stripe payment integration
  • Plausible analytics
  • PostHog A/B testing and feature flags

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Config

func Config(ctx context.Context) config.Config

Return a copy of the current configuration.

func InjectContext

func InjectContext(
	cfg *config.Config,
) echo.MiddlewareFunc

Currying function that returns a middleware function that will inject stuff into the request's context. The currying is used to inject dependencies into the middleware function while still complying with the standard go middleware signature. This middleware will store and retrieve session data and application settings into the context of every request.

Types

type ContextKey

type ContextKey uint

Directories

Path Synopsis
Package config defines the Aetherel configuration.
Package config defines the Aetherel configuration.
package postgres contains utility functions to integrate postgres in your Aetherel application
package postgres contains utility functions to integrate postgres in your Aetherel application
Package server provides general server bootstrapping functionality
Package server provides general server bootstrapping functionality

Jump to