Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InjectContext ¶
func InjectContext( cfg *config.Config, ) echo.MiddlewareFunc
Currying function that returns a middleware function that will inject stuff into the request's context. The currying is used to inject dependencies into the middleware function while still complying with the standard go middleware signature. This middleware will store and retrieve session data and application settings into the context of every request.
Types ¶
type ContextKey ¶
type ContextKey uint
Directories
¶
| Path | Synopsis |
|---|---|
|
Package config defines the Aetherel configuration.
|
Package config defines the Aetherel configuration. |
|
package postgres contains utility functions to integrate postgres in your Aetherel application
|
package postgres contains utility functions to integrate postgres in your Aetherel application |
|
Package server provides general server bootstrapping functionality
|
Package server provides general server bootstrapping functionality |
Click to show internal directories.
Click to hide internal directories.